Django Nomadblog — django-nomadblog 0.5 documentation

### Navigation

- index
- next |
- django-nomadblog 0.5 documentation »

# Django Nomadblog

This is a basic Django application implementing the simplest form of a blogging system. It is capable of managing multible blogs and users. It has been written with an eye put on keeping modularity and flexibility as much as possible, so you won’t find lots of goodies in the code (tagging, related posts, blogroll), but just a couple of features to help you start hacking it to your needs.

Contents:

- Features
- Installation
- Configuration
  - Settings
- Overriding templates
- Passing parameters to views
- Custom view wrappers
- Reverse urls

### Navigation

- index
- next |
- django-nomadblog 0.5 documentation »